@@ -16,9 +16,9 @@ use hdk::prelude::{
     EntryDefRegistration, CreateInput, GetOptions,
 };
 
-pub use entities::{ Collection, Entity, EntityType, EntryModel };
+pub use entities::{ Collection, Entity, EmptyEntity, EntityType, EntryModel };
 pub use errors::{ UtilsResult, UtilsError };
-pub use utils::{ now, find_latest_link, check_entry_type };
+pub use utils::{ now, find_latest_link, check_entry_type, path_from_collection };
 
 
 /// The down-link tag for Entity life-cycles
@@ -28,7 +28,7 @@ pub const TAG_ORIGIN: &'static str = "origin";
 
 /// Get the entity ID for any given entity address
 pub fn get_origin_address(addr: &EntryHash) -> UtilsResult<EntryHash> {
-    let origin_links = get_links(addr.to_owned(), Some(LinkTag::new(TAG_ORIGIN)))?.into_inner();
+    let origin_links = get_links(addr.to_owned(), Some(LinkTag::new(TAG_ORIGIN)))?;
 
     debug!("Found {} [tag: {}] links for address {:?}", origin_links.len(), TAG_ORIGIN, addr );
     match origin_links.len() {
@@ -62,7 +62,7 @@ pub fn fetch_element_latest(id: &EntryHash) -> UtilsResult<(HeaderHash, Element,
 
     let origin_element = element.clone();
 
-    let update_links = get_links(id.to_owned(), Some(LinkTag::new(TAG_UPDATE)))?.into_inner();
+    let update_links = get_links(id.to_owned(), Some(LinkTag::new(TAG_UPDATE)))?;
 
     debug!("Found {} [tag: {}] links for entry: {}", update_links.len(), TAG_UPDATE, id );
     if update_links.len() > 0 {
@@ -131,6 +131,8 @@ where
     Entry: TryFrom<T, Error = WasmError>,
     F: FnOnce(T, Element) -> UtilsResult<T>,
 {
+    // TODO: provide automatic check that the given address is the latest one or an optional flag
+    // to indicate the intension to branch from an older update.
     let (header, element) = fetch_element( addr )?;
 
     let current = check_entry_type( &element, addr )?;
